crypto

package
v2.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const B64CHARSET = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="

Variables

This section is empty.

Functions

func RotCipher

func RotCipher(pt []byte, key []byte, base []byte) []byte

Basic substitution cipher over plaintext by key, uses B64Charset as base

func Shuffle

func Shuffle[E any](a []E)

Shuffles a in place

func ShuffleWith

func ShuffleWith[E any, Z any](a []E, b []Z)

Shuffles a and b, preserving the mapping between the 2 of them

Types

This section is empty.

Jump to